@@ -36,7 +36,7 @@ static void fill_borders P((Display *dpy, Window window, GC gc,
                             int x, int y, int width, int height));
 static void draw_colon P((Display *dpy, Drawable pixmap, Window window));
 
-#if defined (BUILTIN_FONT) || defined (BUILTIN_FONT_2)
+#ifdef BUILTIN_FONTS
 
 static int use_builtin_font;
 
@@ -45,42 +45,67 @@ struct raw_number {
   int width, height;
 };
 
-#endif /* BUILTIN_FONT || BUILTIN_FONT_2 */
+#endif /* BUILTIN_FONTS */
 
-#ifdef BUILTIN_FONT
+#ifdef BUILTIN_FONTS
 
-# include "zero.xbm"
-# include "one.xbm"
-# include "two.xbm"
-# include "three.xbm"
-# include "four.xbm"
-# include "five.xbm"
-# include "six.xbm"
-# include "seven.xbm"
-# include "eight.xbm"
-# include "nine.xbm"
-# include "colon.xbm"
-# include "slash.xbm"
+# include "zero0.xbm"
+# include "one0.xbm"
+# include "two0.xbm"
+# include "three0.xbm"
+# include "four0.xbm"
+# include "five0.xbm"
+# include "six0.xbm"
+# include "seven0.xbm"
+# include "eight0.xbm"
+# include "nine0.xbm"
+# include "colon0.xbm"
+# include "slash0.xbm"
 
-static struct raw_number numbers [] = {
-  { zero_bits, zero_width, zero_height },
-  { one_bits, one_width, one_height },
-  { two_bits, two_width, two_height },
-  { three_bits, three_width, three_height },
-  { four_bits, four_width, four_height },
-  { five_bits, five_width, five_height },
-  { six_bits, six_width, six_height },
-  { seven_bits, seven_width, seven_height },
-  { eight_bits, eight_width, eight_height },
-  { nine_bits, nine_width, nine_height },
-  { colon_bits, colon_width, colon_height },
-  { slash_bits, slash_width, slash_height },
+static struct raw_number numbers_0 [] = {
+  { zero0_bits, zero0_width, zero0_height },
+  { one0_bits, one0_width, one0_height },
+  { two0_bits, two0_width, two0_height },
+  { three0_bits, three0_width, three0_height },
+  { four0_bits, four0_width, four0_height },
+  { five0_bits, five0_width, five0_height },
+  { six0_bits, six0_width, six0_height },
+  { seven0_bits, seven0_width, seven0_height },
+  { eight0_bits, eight0_width, eight0_height },
+  { nine0_bits, nine0_width, nine0_height },
+  { colon0_bits, colon0_width, colon0_height },
+  { slash0_bits, slash0_width, slash0_height },
   { 0, }
 };
 
-#endif /* BUILTIN_FONT */
+# include "zero1.xbm"
+# include "one1.xbm"
+# include "two1.xbm"
+# include "three1.xbm"
+# include "four1.xbm"
+# include "five1.xbm"
+# include "six1.xbm"
+# include "seven1.xbm"
+# include "eight1.xbm"
+# include "nine1.xbm"
+# include "colon1.xbm"
+# include "slash1.xbm"
 
-#ifdef BUILTIN_FONT_2
+static struct raw_number numbers_1 [] = {
+  { zero1_bits, zero1_width, zero1_height },
+  { one1_bits, one1_width, one1_height },
+  { two1_bits, two1_width, two1_height },
+  { three1_bits, three1_width, three1_height },
+  { four1_bits, four1_width, four1_height },
+  { five1_bits, five1_width, five1_height },
+  { six1_bits, six1_width, six1_height },
+  { seven1_bits, seven1_width, seven1_height },
+  { eight1_bits, eight1_width, eight1_height },
+  { nine1_bits, nine1_width, nine1_height },
+  { colon1_bits, colon1_width, colon1_height },
+  { slash1_bits, slash1_width, slash1_height },
+  { 0, }
+};
 
 # include "zero2.xbm"
 # include "one2.xbm"
@@ -111,7 +136,36 @@ static struct raw_number numbers_2 [] = {
   { 0, }
 };
 
-#endif /* BUILTIN_FONT_2 */
+# include "zero3.xbm"
+# include "one3.xbm"
+# include "two3.xbm"
+# include "three3.xbm"
+# include "four3.xbm"
+# include "five3.xbm"
+# include "six3.xbm"
+# include "seven3.xbm"
+# include "eight3.xbm"
+# include "nine3.xbm"
+# include "colon3.xbm"
+# include "slash3.xbm"
+
+static struct raw_number numbers_3 [] = {
+  { zero3_bits, zero3_width, zero3_height },
+  { one3_bits, one3_width, one3_height },
+  { two3_bits, two3_width, two3_height },
+  { three3_bits, three3_width, three3_height },
+  { four3_bits, four3_width, four3_height },
+  { five3_bits, five3_width, five3_height },
+  { six3_bits, six3_width, six3_height },
+  { seven3_bits, seven3_width, seven3_height },
+  { eight3_bits, eight3_width, eight3_height },
+  { nine3_bits, nine3_width, nine3_height },
+  { colon3_bits, colon3_width, colon3_height },
+  { slash3_bits, slash3_width, slash3_height },
+  { 0, }
+};
+
+#endif /* BUILTIN_FONTS */
 
 static char *window_title;
 static char *font_name;
@@ -415,7 +469,7 @@ load_font (screen, fn)
   XFreeGC (dpy, erase_gc);
 }
 
-#if defined (BUILTIN_FONT) || defined (BUILTIN_FONT_2)
+#ifdef BUILTIN_FONTS
 static void
 #ifdef __STDC__
 load_builtin_font (Screen *screen, Visual *visual, int which)
@@ -429,17 +483,19 @@ load_builtin_font (screen, visual, which)
   Display *dpy = DisplayOfScreen (screen);
   int i;
 
-#if defined (BUILTIN_FONT) && defined (BUILTIN_FONT_2)
-  struct raw_number *nums = (which == 1 ? numbers : numbers_2);
-#else /* ! BUILTIN_FONT && BUILTIN_FONT_2 */
-# ifdef BUILTIN_FONT
-  struct raw_number *nums = numbers;
-# else /* BUILTIN_FONT_2 */
-  struct raw_number *nums = numbers_2;
-# endif /* BUILTIN_FONT_2 */
-#endif /* ! BUILTIN_FONT && BUILTIN_FONT_2 */
+  struct raw_number *nums;
+  XImage *image;
 
-  XImage *image =
+  switch (which)
+    {
+    case 0: nums = numbers_0; break;
+    case 1: nums = numbers_1; break;
+    case 2: nums = numbers_2; break;
+    case 3: nums = numbers_3; break;
+    default: abort(); break;
+    }
+
+  image =
     XCreateImage (dpy, visual,
                   1, XYBitmap, 0,       /* depth, format, offset */
                   (char *) 0,           /* data */
@@ -472,7 +528,7 @@ load_builtin_font (screen, visual, which)
                                  (char *) nums[11].bits,
                                  nums[11].width, nums[11].height);
 }
-#endif /* BUILTIN_FONT || BUILTIN_FONT_2 */
+#endif /* BUILTIN_FONTS */
 
 /*  It doesn't matter especially what MAX_SEGS is -- it gets flushed
     when it might fill up -- this number is just for performance tuning
@@ -647,7 +703,8 @@ fill_time_digits P((void))
       m1 = tm->tm_mon % 10;
       d0 = (tm->tm_mday - (tm->tm_mday % 10)) / 10;
       d1 = tm->tm_mday % 10;
-      y0 = (tm->tm_year - (tm->tm_year % 10)) / 10;
+      y0 = tm->tm_year % 100;
+      y0 = (y0 - (y0 % 10)) / 10;
       y1 = tm->tm_year % 10;
 
       switch (date_format)
@@ -685,8 +742,10 @@ fill_time_digits P((void))
           break;
         }
 
+# if 0 /* what was this for? */
       if (twelve_hour_time && time_digits [0] == 0)
         time_digits [0] = -1;
+# endif
     }
 
   if (be_a_pig < 0)
@@ -784,11 +843,11 @@ initialize_digits (screen, visual)
 #endif /* !__STDC__ */
 {
   int i, x;
-#if defined (BUILTIN_FONT) || defined (BUILTIN_FONT_2)
-  if (use_builtin_font)
+#ifdef BUILTIN_FONTS
+  if (use_builtin_font >= 0)
     load_builtin_font (screen, visual, use_builtin_font);
   else
-#endif /* !BUILTIN_FONT && !BUILTIN_FONT_2 */
+#endif /* !BUILTIN_FONTS */
     load_font (screen, font_name);
 
   memset ((char *) memory_pig_zeros,  0, sizeof (memory_pig_zeros));
@@ -965,11 +1024,14 @@ get_resources (screen)
 
   minutes_only = !get_boolean_resource ("seconds", "Seconds");
   font_name = get_string_resource ("font", "Font");
-#if defined (BUILTIN_FONT) || defined (BUILTIN_FONT_2)
-  use_builtin_font = 0;
-  if (!strcasecmp (font_name, "BUILTIN")) use_builtin_font = 1;
+#ifdef BUILTIN_FONTS
+  use_builtin_font = -1;
+  if (!strcasecmp (font_name, "BUILTIN0")) use_builtin_font = 0;
+  if (!strcasecmp (font_name, "BUILTIN1")) use_builtin_font = 1;
   if (!strcasecmp (font_name, "BUILTIN2")) use_builtin_font = 2;
-#endif /* BUILTIN_FONT || BUILTIN_FONT_2 */
+  if (!strcasecmp (font_name, "BUILTIN" )) use_builtin_font = 2;
+  if (!strcasecmp (font_name, "BUILTIN3")) use_builtin_font = 3;
+#endif /* BUILTIN_FONTS */
 
   buf = get_string_resource ("mode", "Mode");
   if (buf == 0 || !strcmp (buf, "12"))
@@ -1174,15 +1236,16 @@ run_digital (screen, window)
         else
           target_frames [n] = base_frames [time_digits [n]];
 
-      if (twelve_hour_time && target_frames [0] && time_digits [0] == 0)
+      n = (be_a_pig >= 0 ? 0 : ndigits-1);
+      if (twelve_hour_time && target_frames [n] && time_digits [n] == 0)
 	{
-	  target_frames [0] = clear_frame;
-	  time_digits [0] = -1;
+	  target_frames [n] = clear_frame;
+	  time_digits [n] = -1;
 	}
-      if (time_digits [0] < 0 && last_time_digits [0] < 0)
-        target_frames [0] = 0;
-      if (last_time_digits [0] == -2) /* evil hack for 12<->24 mode toggle */
-        target_frames [0] = clear_frame;
+      if (time_digits [n] < 0 && last_time_digits [n] < 0)
+        target_frames [n] = 0;
+      if (last_time_digits [n] == -2) /* evil hack for 12<->24 mode toggle */
+        target_frames [n] = clear_frame;
 
       for (tick = 9; tick >= 0; tick--)
         {
