@@ -82,8 +82,11 @@ static XrmOptionDescRec options [] = {
   { "-nocycle",         ".cycle",               XrmoptionNoArg, "False" },
   { "-font",            ".font",                XrmoptionSepArg, 0 },
   { "-fn",              ".font",                XrmoptionSepArg, 0 },
-  { "-builtin",         ".font",                XrmoptionNoArg, "BUILTIN" },
+  { "-builtin",         ".font",                XrmoptionNoArg, "BUILTIN"  },
+  { "-builtin0",        ".font",                XrmoptionNoArg, "BUILTIN0" },
+  { "-builtin1",        ".font",                XrmoptionNoArg, "BUILTIN1" },
   { "-builtin2",        ".font",                XrmoptionNoArg, "BUILTIN2" },
+  { "-builtin3",        ".font",                XrmoptionNoArg, "BUILTIN3" },
   { "-memory",          ".memory",              XrmoptionSepArg, 0 },
   { "-sleaze-level",    ".memory",              XrmoptionSepArg, 0 },
   { "-oink",            ".memory",              XrmoptionNoArg, "Medium" },
@@ -215,7 +218,7 @@ main (argc, argv)
         if (1 == sscanf (s, " %lu %c", &l, &c))
           countdown = l;
         else if (6 == sscanf (s, " %s %d %d:%d:%d %d %c",
-                              &mon, &day, &hour, &min, &sec, &year, &c))
+                              mon, &day, &hour, &min, &sec, &year, &c))
           {
             struct tm tm;
             int imonth = -1;
@@ -314,8 +317,8 @@ main (argc, argv)
     }
   else
     {
-      int xmargin = 10;
-      int ymargin = 10;
+      int ymargin = (h / 8) + 1;
+      int xmargin = ymargin;
       Dimension ow, oh, bw;
       Arg av [20];
       int ac;
@@ -402,6 +405,8 @@ where options include\n\
   -noseconds                    Don't display seconds.\n\
   -cycle                        Do color-cycling.\n\
   -nocycle                      Don't do color-cycling (default).\n\
+  -countdown <date>             Display a countdown instead of a clock.\n\
+                                Run `-countdown foo' to see date syntax.\n\
   -display <host:dpy>           The display to run on.\n\
   -visual <visual-class>        The visual to use.\n\
   -install                      Allocate a private colormap.\n\
@@ -418,29 +423,23 @@ where options include\n\
   -window                       Opposite of -root (default).\n\
   -datemode <MMDDYY | DDMMYY>   How to format the date.\n\
 ", hacked_version2, progname, progname);
-#if defined (BUILTIN_FONT) && defined (BUILTIN_FONT_2)
+#ifdef BUILTIN_FONTS
   fprintf (stderr, "\
-  -font or -fn <font>           Name of an X font to use, or the string\n\
-                                \"BUILTIN\", meaning to use the large builtin\n\
-                                font (this is the default), or \"BUILTIN2\",\n\
-                                meaning to use the even larger builtin font.\n\
-  -builtin                      Same as -font BUILTIN.\n\
+  -font or -fn <font>           Name of an X font or built-in font to use.\n\
+                                There are four builtin fonts, named\n\
+                                \"BUILTIN0\", \"BUILTIN1\", \"BUILTIN2\",\n\
+                                and \"BUILTIN3\", with #2 being the default.\n\
+  -builtin0                     Same as -font BUILTIN0.\n\
+  -builtin1                     Same as -font BUILTIN1.\n\
   -builtin2                     Same as -font BUILTIN2.\n\
-");
-#else /* ! (BUILTIN_FONT && BUILTIN_FONT_2) */
-#if (defined (BUILTIN_FONT) || defined (BUILTIN_FONT_2))
-  fprintf (stderr, "\
-  -font or -fn <font>           Name of an X font to use, or the string\n\
-                                \"BUILTIN\", meaning to use the large builtin\n\
-                                font (this is the default).\n\
   -builtin                      Same as -font BUILTIN.\n\
+  -builtin3                     Same as -font BUILTIN3.\n\
 ");
-#else /* ! (BUILTIN_FONT || BUILTIN_FONT_2) */
+#else /* !BUILTIN_FONTS */
   fprintf (stderr, "\
   -font or -fn <font>           Name of an X font to use.\n\
 ");
-#endif /* ! (BUILTIN_FONT || BUILTIN_FONT_2) */
-#endif /* ! (BUILTIN_FONT && BUILTIN_FONT_2) */
+#endif /* !BUILTIN_FONTS */
   fprintf (stderr, "\
   -memory <high|medium|low>     Tune the memory versus bandwidth consumption;\n\
                                 default is \"low\".\n\
@@ -449,10 +448,10 @@ where options include\n\
   -transparent                  Make the window background be transparent,\n\
                                 if possible.\n\
   -nontransparent               Don't.\n\n");
-#if !defined(BUILTIN_FONT) && !defined(BUILTIN_FONT_2)
+#ifndef BUILTIN_FONTS
   fprintf(stderr,
           "This version has been compiled without the builtin fonts.\n\n");
-#endif
+#endif /* BUILTIN_FONTS */
 }
 
 static void
